@@ -2,11 +2,17 @@
 API for Numpy usage.
 """
 
+import functools
 from typing import Any, Callable, Optional, Sequence, Tuple
 
-import functools
 import numpy as np  # type: ignore
 
+from targetran._check import (
+    _check_shear_input,
+    _check_translate_input,
+    _check_crop_input,
+    _check_input_range
+)
 from targetran._functional import (
     _np_convert,
     _np_range,
@@ -17,7 +23,6 @@ from targetran._functional import (
     _np_pad_image,
     _np_gather_image
 )
-
 from targetran._transform import (
     _affine_transform,
     _flip_left_right,
@@ -106,8 +111,11 @@ def shear(
         image: np.ndarray,
         bboxes: np.ndarray,
         labels: np.ndarray,
-        angle_deg: float
+        angle_deg: float,
+        check_input: bool = True
 ) -> Tuple[np.ndarray, np.ndarray, np.ndarray]:
+    if check_input:
+        _check_shear_input(angle_deg)
     return _shear(
         image, bboxes, labels, _np_convert(angle_deg),
         _np_convert, np.tan, np.shape, np.reshape, np.expand_dims, np.squeeze,
@@ -123,8 +131,11 @@ def translate(
         bboxes: np.ndarray,
         labels: np.ndarray,
         translate_height: int,
-        translate_width: int
+        translate_width: int,
+        check_input: bool = True
 ) -> Tuple[np.ndarray, np.ndarray, np.ndarray]:
+    if check_input:
+        _check_translate_input(image.shape, translate_height, translate_width)
     return _translate(
         image, bboxes, labels,
         _np_convert(translate_height), _np_convert(translate_width),
@@ -156,8 +167,11 @@ def crop(
         offset_height: int,
         offset_width: int,
         cropped_image_height: int,
-        cropped_image_width: int
+        cropped_image_width: int,
+        check_input: bool = True
 ) -> Tuple[np.ndarray, np.ndarray, np.ndarray]:
+    if check_input:
+        _check_crop_input(image.shape, offset_height, offset_width)
     return _crop(
         image, bboxes, labels,
         _np_convert(offset_height), _np_convert(offset_width),
@@ -227,8 +241,11 @@ class CombineAffine(RandomTransform):
             probability: float = 0.7,
             seed: Optional[int] = None
     ) -> None:
-        self._transforms = transforms
         super().__init__(_np_affine_transform, probability, seed)
+        self._transforms = transforms
+        self._identity_mat = np.expand_dims(np.array([
+            [1.0, 0.0, 0.0], [0.0, 1.0, 0.0], [0.0, 0.0, 1.0]
+        ]), axis=0)
 
     def _combine_mats(
             self,
@@ -240,20 +257,21 @@ class CombineAffine(RandomTransform):
               for i, t in enumerate(self._transforms)]
         ))
 
-        identity_mat = np.expand_dims(np.array([
-            [1.0, 0.0, 0.0], [0.0, 1.0, 0.0], [0.0, 0.0, 1.0]
-        ]), axis=0)
         conditions = np.reshape(rand_fn() < probs, (len(probs), 1, 1))
         image_dest_tran_mats = np.where(
-            conditions, image_dest_tran_mats, identity_mat
+            conditions, image_dest_tran_mats, self._identity_mat
         )
         bboxes_tran_mats = np.where(
-            conditions, bboxes_tran_mats, identity_mat
+            conditions, bboxes_tran_mats, self._identity_mat
         )
 
-        image_dest_tran_mat = functools.reduce(np.matmul, image_dest_tran_mats)
-        # Note the reversed order for the bboxes matrices.
-        bboxes_tran_mat = functools.reduce(np.matmul, bboxes_tran_mats[::-1])
+        image_dest_tran_mat = functools.reduce(
+            np.matmul, image_dest_tran_mats
+        )
+        # Note the reversed order for the bboxes tran matrices.
+        bboxes_tran_mat = functools.reduce(
+            np.matmul, bboxes_tran_mats[::-1]
+        )
         return image_dest_tran_mat, bboxes_tran_mat
 
     def __call__(
@@ -334,8 +352,8 @@ class RandomRotate(RandomTransform):
             probability: float = 0.7,
             seed: Optional[int] = None
     ) -> None:
+        _check_input_range(angle_deg_range, None, "angle_deg_range")
         super().__init__(rotate, probability, seed)
-        assert angle_deg_range[0] < angle_deg_range[1]
         self.angle_deg_range = angle_deg_range
 
     def _get_angle_deg(self, rand_fn: Callable[..., np.ndarray]) -> np.ndarray:
@@ -372,8 +390,8 @@ class RandomShear(RandomTransform):
             probability: float = 0.7,
             seed: Optional[int] = None
     ) -> None:
+        _check_input_range(angle_deg_range, (-90.0, 90.0), "angle_deg_range")
         super().__init__(shear, probability, seed)
-        assert -90.0 < angle_deg_range[0] < angle_deg_range[1] < 90.0
         self.angle_deg_range = angle_deg_range
 
     def _get_angle_deg(self, rand_fn: Callable[..., np.ndarray]) -> np.ndarray:
@@ -396,7 +414,7 @@ class RandomShear(RandomTransform):
             **kwargs: Any
     ) -> Tuple[np.ndarray, np.ndarray, np.ndarray]:
         return super().__call__(
-            image, bboxes, labels, self._get_angle_deg(self._rand_fn)
+            image, bboxes, labels, self._get_angle_deg(self._rand_fn), False
         )
 
 
@@ -409,6 +427,14 @@ class RandomTranslate(RandomTransform):
             probability: float = 0.7,
             seed: Optional[int] = None
     ) -> None:
+        _check_input_range(
+            translate_height_fraction_range, (-1.0, 1.0),
+            "translate_height_fraction_range"
+        )
+        _check_input_range(
+            translate_width_fraction_range, (-1.0, 1.0),
+            "translate_width_fraction_range"
+        )
         super().__init__(translate, probability, seed)
         self.translate_height_fraction_range = translate_height_fraction_range
         self.translate_width_fraction_range = translate_width_fraction_range
@@ -453,7 +479,7 @@ class RandomTranslate(RandomTransform):
         translate_height, translate_width = \
             self._get_translate_height_and_width(image, self._rand_fn)
         return super().__call__(
-            image, bboxes, labels, translate_height, translate_width
+            image, bboxes, labels, translate_height, translate_width, False
         )
 
 
@@ -466,6 +492,12 @@ class RandomCrop(RandomTransform):
             probability: float = 0.7,
             seed: Optional[int] = None
     ) -> None:
+        _check_input_range(
+            crop_height_fraction_range, (0.0, 1.0), "crop_height_fraction_range"
+        )
+        _check_input_range(
+            crop_width_fraction_range, (0.0, 1.0), "crop_width_fraction_range"
+        )
         super().__init__(crop, probability, seed)
         self.crop_height_fraction_range = crop_height_fraction_range
         self.crop_width_fraction_range = crop_width_fraction_range
@@ -488,7 +520,7 @@ class RandomCrop(RandomTransform):
 
         return super().__call__(
             image, bboxes, labels,
-            offset_height, offset_width, cropped_height, cropped_width
+            offset_height, offset_width, cropped_height, cropped_width, False
         )
 
 
