@@ -2,12 +2,19 @@
 API for TensorFlow usage.
 """
 
+import functools
 from typing import Any, Callable, Optional, Sequence, Tuple, TypeVar
 
-import functools
 import numpy as np  # type: ignore
 import tensorflow as tf  # type: ignore
 
+
+from targetran._check import (
+    _check_shear_input,
+    _check_translate_input,
+    _check_crop_input,
+    _check_input_range
+)
 from targetran._functional import (
     _tf_convert,
     _tf_round_to_int,
@@ -15,7 +22,6 @@ from targetran._functional import (
     _tf_pad_image,
     _tf_gather_image
 )
-
 from targetran._transform import (
     _affine_transform,
     _flip_left_right,
@@ -149,8 +155,11 @@ def tf_shear(
         image: tf.Tensor,
         bboxes: tf.Tensor,
         labels: tf.Tensor,
-        angle_deg: float
+        angle_deg: float,
+        check_input: bool = True
 ) -> Tuple[tf.Tensor, tf.Tensor, tf.Tensor]:
+    if check_input:
+        _check_shear_input(angle_deg)
     return _shear(
         image, bboxes, labels, _tf_convert(angle_deg),
         _tf_convert, tf.tan, tf.shape, tf.reshape, tf.expand_dims, tf.squeeze,
@@ -166,8 +175,13 @@ def tf_translate(
         bboxes: tf.Tensor,
         labels: tf.Tensor,
         translate_height: int,
-        translate_width: int
+        translate_width: int,
+        check_input: bool = True
 ) -> Tuple[tf.Tensor, tf.Tensor, tf.Tensor]:
+    if check_input:
+        _check_translate_input(
+            image.get_shape(), translate_height, translate_width
+        )
     return _translate(
         image, bboxes, labels,
         _tf_convert(translate_height), _tf_convert(translate_width),
@@ -199,8 +213,11 @@ def tf_crop(
         offset_height: int,
         offset_width: int,
         cropped_image_height: int,
-        cropped_image_width: int
+        cropped_image_width: int,
+        check_input: bool = True
 ) -> Tuple[tf.Tensor, tf.Tensor, tf.Tensor]:
+    if check_input:
+        _check_crop_input(image.get_shape(), offset_height, offset_width)
     return _crop(
         image, bboxes, labels,
         _tf_convert(offset_height), _tf_convert(offset_width),
@@ -271,8 +288,11 @@ class TFCombineAffine(TFRandomTransform):
             probability: float = 0.7,
             seed: Optional[int] = None
     ) -> None:
-        self._transforms = transforms
         super().__init__(_tf_affine_transform, probability, seed)
+        self._transforms = transforms
+        self._identity_mat = tf.expand_dims(tf.constant([
+            [1.0, 0.0, 0.0], [0.0, 1.0, 0.0], [0.0, 0.0, 1.0]
+        ]), axis=0)
 
     def _combine_mats(
             self,
@@ -284,25 +304,21 @@ class TFCombineAffine(TFRandomTransform):
               for i, t in enumerate(self._transforms)]
         ))
 
-        identity_mat = tf.expand_dims(tf.constant([
-            [1.0, 0.0, 0.0], [0.0, 1.0, 0.0], [0.0, 0.0, 1.0]
-        ]), axis=0)
         conditions = tf.reshape(rand_fn() < probs, (len(probs), 1, 1))
         image_dest_tran_mats = tf.where(
-            conditions, image_dest_tran_mats, identity_mat
+            conditions, image_dest_tran_mats, self._identity_mat
         )
         bboxes_tran_mats = tf.where(
-            conditions, bboxes_tran_mats, identity_mat
+            conditions, bboxes_tran_mats, self._identity_mat
         )
 
         image_dest_tran_mat = functools.reduce(
             tf.matmul, tf.unstack(image_dest_tran_mats)
         )
-        # Note the reversed order for the bboxes matrices.
+        # Note the reversed order for the bboxes tran matrices.
         bboxes_tran_mat = functools.reduce(
             tf.matmul, tf.unstack(bboxes_tran_mats)[::-1]
         )
-
         return image_dest_tran_mat, bboxes_tran_mat
 
     def __call__(
@@ -383,8 +399,8 @@ class TFRandomRotate(TFRandomTransform):
             probability: float = 0.7,
             seed: Optional[int] = None
     ) -> None:
+        _check_input_range(angle_deg_range, None, "angle_deg_range")
         super().__init__(tf_rotate, probability, seed)
-        assert angle_deg_range[0] < angle_deg_range[1]
         self.angle_deg_range = angle_deg_range
 
     def _get_angle_deg(self, rand_fn: Callable[..., tf.Tensor]) -> tf.Tensor:
@@ -421,8 +437,8 @@ class TFRandomShear(TFRandomTransform):
             probability: float = 0.7,
             seed: Optional[int] = None
     ) -> None:
+        _check_input_range(angle_deg_range, (-90.0, 90.0), "angle_deg_range")
         super().__init__(tf_shear, probability, seed)
-        assert -90.0 < angle_deg_range[0] < angle_deg_range[1] < 90.0
         self.angle_deg_range = angle_deg_range
 
     def _get_angle_deg(self, rand_fn: Callable[..., tf.Tensor]) -> tf.Tensor:
@@ -447,7 +463,7 @@ class TFRandomShear(TFRandomTransform):
             **kwargs: Any
     ) -> Tuple[tf.Tensor, tf.Tensor, tf.Tensor]:
         return super().__call__(
-            image, bboxes, labels, self._get_angle_deg(self._rand_fn)
+            image, bboxes, labels, self._get_angle_deg(self._rand_fn), False
         )
 
 
@@ -460,6 +476,14 @@ class TFRandomTranslate(TFRandomTransform):
             probability: float = 0.7,
             seed: Optional[int] = None
     ) -> None:
+        _check_input_range(
+            translate_height_fraction_range, (-1.0, 1.0),
+            "translate_height_fraction_range"
+        )
+        _check_input_range(
+            translate_width_fraction_range, (-1.0, 1.0),
+            "translate_width_fraction_range"
+        )
         super().__init__(tf_translate, probability, seed)
         self.translate_height_fraction_range = translate_height_fraction_range
         self.translate_width_fraction_range = translate_width_fraction_range
@@ -500,7 +524,7 @@ class TFRandomTranslate(TFRandomTransform):
         translate_height, translate_width = \
             self._get_translate_height_and_width(image, self._rand_fn)
         return super().__call__(
-            image, bboxes, labels, translate_height, translate_width
+            image, bboxes, labels, translate_height, translate_width, False
         )
 
 
@@ -513,6 +537,12 @@ class TFRandomCrop(TFRandomTransform):
             probability: float = 0.7,
             seed: Optional[int] = None
     ) -> None:
+        _check_input_range(
+            crop_height_fraction_range, (0.0, 1.0), "crop_height_fraction_range"
+        )
+        _check_input_range(
+            crop_width_fraction_range, (0.0, 1.0), "crop_width_fraction_range"
+        )
         super().__init__(tf_crop, probability, seed)
         self.crop_height_fraction_range = crop_height_fraction_range
         self.crop_width_fraction_range = crop_width_fraction_range
@@ -535,7 +565,7 @@ class TFRandomCrop(TFRandomTransform):
 
         return super().__call__(
             image, bboxes, labels,
-            offset_height, offset_width, cropped_height, cropped_width
+            offset_height, offset_width, cropped_height, cropped_width, False
         )
 
 
